keyLength constant
int
const keyLength
Required length of the master key supplied by a KeyProvider.
Implementation
static const int keyLength = 32;
Required length of the master key supplied by a KeyProvider.
static const int keyLength = 32;