wipe static method

void wipe(
  1. Uint8List bytes
)

Overwrites bytes with zeros.

Used on plaintext and key material once it is no longer needed, so it does not linger in the heap until garbage collection.

Implementation

static void wipe(Uint8List bytes) => bytes.fillRange(0, bytes.length, 0);